test

Attribute Macro test 

#[test]
Marks an async fn as a runite-driven test.

Generates a #[test] wrapper that drives the test’s future to completion with runite::block_on. The test function may return anything that implements [std::process::Termination] (for example Result<(), E> so the body can use ?). Test attributes such as #[ignore] and #[should_panic] placed below #[runite::test] are forwarded to the generated test.

To use a renamed runite dependency, pass the path: #[runite::test(crate = "my_runite")].